@@ -11,10 +11,10 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Author::RWSTAUNER;
-# git description: v4.208-1-gf69e9f5
+# git description: v4.209-7-gcb0237c
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
-$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.209';
+$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.210';
 # ABSTRACT: RWSTAUNER's Dist::Zilla config
 
 use Moose;
@@ -142,6 +142,15 @@ has releaser => (
   },
 );
 
+has readme_phase => (
+  is         => 'ro',
+  isa        => 'Str',
+  lazy       => 1,
+  default    => sub {
+    $_[0]->_config(readme_phase => $ENV{DZIL_README_PHASE} || 'release');
+  }
+);
+
 has skip_plugins => (
   is         => 'ro',
   isa        => 'Maybe[Regexp]',
@@ -316,7 +325,19 @@ sub configure {
         ':version' => '0.142180', # 'phase'
         type       => 'markdown', # L<> to metacpan
         location   => 'root',
-        phase      => 'release',
+        phase      => $self->readme_phase,
+      }
+    ],
+    [
+      # ... and add status badges to it.
+      'GitHubREADME::Badge' => {
+        ':version' => '0.16', # 'phase', svg
+        phase      => $self->readme_phase,
+        badges     => [qw(
+          travis
+          coveralls
+          cpants
+        )],
       }
     ],
     [ CopyFilesFromRelease => { filename => [ @{ $self->copy_files } ] } ],
@@ -531,7 +552,7 @@ Dist::Zilla::PluginBundle::Author::RWSTAUNER - RWSTAUNER's Dist::Zilla config
 
 =head1 VERSION
 
-version 4.209
+version 4.210
 
 =head1 SYNOPSIS
 
@@ -669,6 +690,13 @@ This bundle is roughly equivalent to the following (generated) F<dist.ini>:
   phase    = release
   type     = markdown
 
+  [GitHubREADME::Badge]
+  :version = 0.16
+  badges   = travis
+  badges   = coveralls
+  badges   = cpants
+  phase    = release
+
   [CopyFilesFromRelease]
   filename = LICENSE
 
